==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RangeCategorySeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { CategorySeriesDescription } from "./CategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RangeCategorySeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeCategorySeriesDescription, _super);
    function RangeCategorySeriesDescription() {
        var _this = _super.call(this) || this;
        _this.d4 = null;
        _this.d3 = null;
        return _this;
    }
    RangeCategorySeriesDescription.prototype.get_type = function () {
        return "RangeCategorySeries";
    };
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "lowMemberPath", {
        get: function () {
            return this.d4;
        },
        set: function (a) {
            this.d4 = a;
            this.e("LowMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "highMemberPath", {
        get: function () {
            return this.d3;
        },
        set: function (a) {
            this.d3 = a;
            this.e("HighMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    RangeCategorySeriesDescription.$t = markType(RangeCategorySeriesDescription, 'RangeCategorySeriesDescription', CategorySeriesDescription.$);
    return RangeCategorySeriesDescription;
}(CategorySeriesDescription));
export { RangeCategorySeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/RangeCategorySeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { CategorySeriesDescription } from "./CategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RangeCategorySeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeCategorySeriesDescription, _super);
    function RangeCategorySeriesDescription() {
        var _this = _super.call(this) || this;
        _this.gc = null;
        _this.gb = null;
        _this.ga = null;
        _this.f9 = null;
        return _this;
    }
    RangeCategorySeriesDescription.prototype.get_type = function () {
        return "RangeCategorySeries";
    };
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "lowMemberPath", {
        get: function () {
            return this.gc;
        },
        set: function (a) {
            this.gc = a;
            this.g("LowMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "highMemberPath", {
        get: function () {
            return this.gb;
        },
        set: function (a) {
            this.gb = a;
            this.g("HighMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "highlightedLowMemberPath", {
        get: function () {
            return this.ga;
        },
        set: function (a) {
            this.ga = a;
            this.g("HighlightedLowMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RangeCategorySeriesDescription.prototype, "highlightedHighMemberPath", {
        get: function () {
            return this.f9;
        },
        set: function (a) {
            this.f9 = a;
            this.g("HighlightedHighMemberPath");
        },
        enumerable: false,
        configurable: true
    });
    RangeCategorySeriesDescription.$t = markType(RangeCategorySeriesDescription, 'RangeCategorySeriesDescription', CategorySeriesDescription.$);
    return RangeCategorySeriesDescription;
}(CategorySeriesDescription));
export { RangeCategorySeriesDescription };
